Module array_store

Module array_store 

Storage for PostScript array contents.

Each array is a contiguous range of PsObject values. The EntityId indexes into the entity table, which provides the base offset into the flat data vector. Subarrays use start and len fields in the PsObject for view support.

Structs

ArrayStore
Storage for PostScript array element data.