#[non_exhaustive]pub enum ExpandError {
MultiPageNeedsToken {
path: String,
suggestion: String,
},
}Expand description
Why a template could not be expanded for a given page.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MultiPageNeedsToken
A job produced a second page under a template with no %d, so every
page would land on the same path.