StringStore

Struct StringStore 

pub struct StringStore {
    pub entities: EntityTable,
    /* private fields */
}
Storage for PostScript string byte data.

Fields

entities: EntityTable

Implementations

Source

impl StringStore

pub fn new() -> Self

pub fn allocate(&mut self, len: usize) -> EntityId

Allocate len zero-filled bytes, returning an EntityId.

pub fn allocate_from(&mut self, bytes: &[u8]) -> EntityId

Allocate and copy bytes into the store.

pub fn allocate_from_with( &mut self, bytes: &[u8], save_level: u16, global: bool, created_after_save: u32, ) -> EntityId

Allocate and copy bytes with a specific save level and global flag.

pub fn allocate_with( &mut self, len: usize, save_level: u16, global: bool, created_after_save: u32, ) -> EntityId

Allocate with a specific save level and global flag.

pub fn get(&self, entity: EntityId, start: u32, len: u32) -> &[u8]

Get a slice of the string data via entity table indirection. start is the byte offset from the entity’s base; len is the number of bytes.

pub fn get_mut(&mut self, entity: EntityId, start: u32, len: u32) -> &mut [u8]

Get a mutable slice of the string data via entity table indirection. start is the byte offset from the entity’s base; len is the number of bytes.

pub fn put_byte(&mut self, entity: EntityId, offset: u32, byte: u8)

Set a single byte.

pub fn get_byte(&self, entity: EntityId, offset: u32) -> u8

Get a single byte.

pub fn cow_copy(&mut self, entity: EntityId) -> EntityId

Copy entity data to a new region (for COW). Returns the new EntityId pointing to the copy. The original entity’s offset is updated to point at the copy, so the original EntityId now sees the new data.

pub fn swap_offsets(&mut self, a: EntityId, b: EntityId)

Swap offsets between two entities (used by restore).

pub fn data(&self) -> &[u8]

Access to the backing data (for advanced operations).